==> brmo-stufbg204-1.5.0-sources.jar: nl/egem/stuf/sector/bg/_0204/ADRAntwoord.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * adres binnen antwoordberichten
 * 
 * <p>Java class for ADR-antwoord complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ADR-antwoord">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}ADR-fund">
 *       &lt;sequence>
 *         &lt;element name="ADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-fund" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element name="ADRADROSU" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}ADRADROSU-rel">
 *                 &lt;sequence>
 *                   &lt;element name="ADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-kennisgeving"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ADR-antwoord", propOrder = {
    "adr",
    "adradrosu"
})
public class ADRAntwoord
    extends ADRFund
{

    @XmlElement(name = "ADR")
    protected List<ADRFund> adr;
    @XmlElement(name = "ADRADROSU", nillable = true)
    protected List<ADRAntwoord.ADRADROSU> adradrosu;

    /**
     * Gets the value of the adr property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the adr property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getADR().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ADRFund }
     * 
     * 
     */
    public List<ADRFund> getADR() {
        if (adr == null) {
            adr = new ArrayList<ADRFund>();
        }
        return this.adr;
    }

    /**
     * Gets the value of the adradrosu property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the adradrosu property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getADRADROSU().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ADRAntwoord.ADRADROSU }
     * 
     * 
     */
    public List<ADRAntwoord.ADRADROSU> getADRADROSU() {
        if (adradrosu == null) {
            adradrosu = new ArrayList<ADRAntwoord.ADRADROSU>();
        }
        return this.adradrosu;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}ADRADROSU-rel">
     *       &lt;sequence>
     *         &lt;element name="ADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-kennisgeving"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "adr"
    })
    public static class ADRADROSU
        extends ADRADROSURel
    {

        @XmlElement(name = "ADR", required = true, nillable = true)
        protected ADRKennisgeving adr;

        /**
         * Gets the value of the adr property.
         * 
         * @return
         *     possible object is
         *     {@link ADRKennisgeving }
         *     
         */
        public ADRKennisgeving getADR() {
            return adr;
        }

        /**
         * Sets the value of the adr property.
         * 
         * @param value
         *     allowed object is
         *     {@link ADRKennisgeving }
         *     
         */
        public void setADR(ADRKennisgeving value) {
            this.adr = value;
        }

    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/sector/bg/_0204/ADRAntwoord.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * adres binnen antwoordberichten
 * 
 * <p>Java class for ADR-antwoord complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ADR-antwoord"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}ADR-fund"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="ADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-fund" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;element name="ADRADROSU" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}ADRADROSU-rel"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="ADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-kennisgeving"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ADR-antwoord", propOrder = {
    "adr",
    "adradrosu"
})
public class ADRAntwoord
    extends ADRFund
{

    @XmlElement(name = "ADR")
    protected List<ADRFund> adr;
    @XmlElement(name = "ADRADROSU", nillable = true)
    protected List<ADRAntwoord.ADRADROSU> adradrosu;

    /**
     * Gets the value of the adr property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the adr property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getADR().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ADRFund }
     * 
     * 
     */
    public List<ADRFund> getADR() {
        if (adr == null) {
            adr = new ArrayList<ADRFund>();
        }
        return this.adr;
    }

    /**
     * Gets the value of the adradrosu property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the adradrosu property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getADRADROSU().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ADRAntwoord.ADRADROSU }
     * 
     * 
     */
    public List<ADRAntwoord.ADRADROSU> getADRADROSU() {
        if (adradrosu == null) {
            adradrosu = new ArrayList<ADRAntwoord.ADRADROSU>();
        }
        return this.adradrosu;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}ADRADROSU-rel"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="ADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-kennisgeving"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "adr"
    })
    public static class ADRADROSU
        extends ADRADROSURel
    {

        @XmlElement(name = "ADR", required = true, nillable = true)
        protected ADRKennisgeving adr;

        /**
         * Gets the value of the adr property.
         * 
         * @return
         *     possible object is
         *     {@link ADRKennisgeving }
         *     
         */
        public ADRKennisgeving getADR() {
            return adr;
        }

        /**
         * Sets the value of the adr property.
         * 
         * @param value
         *     allowed object is
         *     {@link ADRKennisgeving }
         *     
         */
        public void setADR(ADRKennisgeving value) {
            this.adr = value;
        }

    }

}
